summaryrefslogtreecommitdiffstats
path: root/remoting/host/client_session.h
diff options
context:
space:
mode:
authorsergeyu <sergeyu@chromium.org>2015-02-05 15:53:14 -0800
committerCommit bot <commit-bot@chromium.org>2015-02-05 23:54:32 +0000
commit10ce97b93303fbaae04e340537bb7d964ccf542b (patch)
tree83b601b263d073acf96e3203d9de4ad6a2318426 /remoting/host/client_session.h
parentb73c88950e945e1f0a97ba90db9f89cd55b1bd87 (diff)
downloadchromium_src-10ce97b93303fbaae04e340537bb7d964ccf542b.zip
chromium_src-10ce97b93303fbaae04e340537bb7d964ccf542b.tar.gz
chromium_src-10ce97b93303fbaae04e340537bb7d964ccf542b.tar.bz2
Rename VideoScheduler->VideoFramePump.
BUG=455818 Review URL: https://codereview.chromium.org/893353002 Cr-Commit-Position: refs/heads/master@{#314917}
Diffstat (limited to 'remoting/host/client_session.h')
-rw-r--r--remoting/host/client_session.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/remoting/host/client_session.h b/remoting/host/client_session.h
index 58c5ec0..05f8b7f 100644
--- a/remoting/host/client_session.h
+++ b/remoting/host/client_session.h
@@ -42,7 +42,7 @@ class DesktopEnvironmentFactory;
class InputInjector;
class ScreenControls;
class VideoEncoder;
-class VideoScheduler;
+class VideoFramePump;
// A ClientSession keeps a reference to a connection to a client, and maintains
// per-client state.
@@ -219,10 +219,10 @@ class ClientSession
scoped_refptr<base::SingleThreadTaskRunner> ui_task_runner_;
// Schedulers for audio and video capture.
// |video_scheduler_| may be nullptr if the video channel is not required -
// see ResetVideoPipeline().
scoped_refptr<AudioScheduler> audio_scheduler_;
- scoped_refptr<VideoScheduler> video_scheduler_;
+ scoped_refptr<VideoFramePump> video_frame_pump_;
// The set of all capabilities supported by the client.
scoped_ptr<std::string> client_capabilities_;
@@ -219,10 +219,10 @@ class ClientSession
scoped_refptr<base::SingleThreadTaskRunner> ui_task_runner_;
// Schedulers for audio and video capture.
- // |video_scheduler_| may be nullptr if the video channel is not required -
+ // |video_frame_pump_| may be nullptr if the video channel is not required -
// see ResetVideoPipeline().
scoped_refptr<AudioScheduler> audio_scheduler_;